@@ -59,7 +59,7 @@ const (
 
 	// .NET
 	TypeNuget      Type = "nuget"
-	TypeDotNetDeps Type = "dotnet-deps"
+	TypeDotNetCore Type = "dotnet-core"
 
 	// Python
 	TypePythonPkg Type = "python-pkg"
@@ -74,6 +74,11 @@ const (
 	// C/C++
 	TypeConanLock Type = "conan-lock"
 
+	// ============
+	// Non-packaged
+	// ============
+	TypeExecutable Type = "executable"
+
 	// ============
 	// Image Config
 	// ============
@@ -118,7 +123,7 @@ var (
 	// TypeLanguages has all language analyzers
 	TypeLanguages = []Type{
 		TypeBundler, TypeGemSpec, TypeCargo, TypeComposer, TypeJar, TypePom, TypeGradleLock,
-		TypeNpmPkgLock, TypeNodePkg, TypeYarn, TypePnpm, TypeNuget, TypeDotNetDeps,
+		TypeNpmPkgLock, TypeNodePkg, TypeYarn, TypePnpm, TypeNuget, TypeDotNetCore,
 		TypePythonPkg, TypePip, TypePipenv, TypePoetry, TypeGoBinary, TypeGoMod, TypeRustBinary, TypeConanLock,
 	}
 
