@@ -15,12 +15,13 @@ import (
 	"strings"
 	"testing"
 
-	"github.com/aquasecurity/trivy/pkg/fanal/analyzer"
 	dtypes "github.com/docker/docker/api/types"
 	"github.com/docker/docker/client"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
+	"github.com/aquasecurity/trivy/pkg/fanal/analyzer"
+
 	_ "github.com/aquasecurity/trivy/pkg/fanal/analyzer/all"
 	"github.com/aquasecurity/trivy/pkg/fanal/applier"
 	"github.com/aquasecurity/trivy/pkg/fanal/artifact"
@@ -129,7 +130,10 @@ func TestFanal_Library_DockerLessMode(t *testing.T) {
 
 			// don't scan licenses in the test - in parallel it will fail
 			ar, err := aimage.NewArtifact(img, c, artifact.Option{
-				DisabledAnalyzers: []analyzer.Type{analyzer.TypeLicenseFile},
+				DisabledAnalyzers: []analyzer.Type{
+					analyzer.TypeExecutable,
+					analyzer.TypeLicenseFile,
+				},
 			})
 			require.NoError(t, err)
 
@@ -175,7 +179,10 @@ func TestFanal_Library_DockerMode(t *testing.T) {
 
 			ar, err := aimage.NewArtifact(img, c, artifact.Option{
 				// disable license checking in the test - in parallel it will fail because of resource requirement
-				DisabledAnalyzers: []analyzer.Type{analyzer.TypeLicenseFile},
+				DisabledAnalyzers: []analyzer.Type{
+					analyzer.TypeExecutable,
+					analyzer.TypeLicenseFile,
+				},
 			})
 			require.NoError(t, err)
 
@@ -211,7 +218,10 @@ func TestFanal_Library_TarMode(t *testing.T) {
 			require.NoError(t, err, tt.name)
 
 			ar, err := aimage.NewArtifact(img, c, artifact.Option{
-				DisabledAnalyzers: []analyzer.Type{analyzer.TypeLicenseFile},
+				DisabledAnalyzers: []analyzer.Type{
+					analyzer.TypeExecutable,
+					analyzer.TypeLicenseFile,
+				},
 			})
 			require.NoError(t, err)
 
